@@ -2,7 +2,7 @@
 #'
 #' @export
 #' @param x An LSID number. Required.
-#' @param ... Curl options passed on to \code{\link[httr]{GET}}
+#' @param ... Curl options passed on to \code{\link[crul]{verb-GET}}
 #' @references http://www.organismnames.com
 #' @return A data.frame
 #' @examples \dontrun{
@@ -12,19 +12,20 @@
 #' ion(1280626) # puma concolor
 #' }
 ion <- function(x, ...) {
-  res <- GET(ion_base(), query = list(lsid = x), ...)
-  stop_for_status(res)
-  xml <- xml2::read_xml(con_utf8(res))
+  cli <- crul::HttpClient$new(ion_base(), opts = list(...))
+  res <- cli$get(query = list(lsid = x))
+  res$raise_for_status()
+  xml <- xml2::read_xml(res$parse("UTF-8"))
   dc <- as.list(sapply(c('identifier', 'Title'), function(z) {
     xml_text(xml_find_all(xml, paste0("//dc:", z), xml_ns(xml)))
   }))
   tdwg <- as.list(
-    setNames(
+    stats::setNames(
       xml_text(xml_find_all(xml, "//tdwg_tn:nameComplete", xml_ns(xml))),
       "nameComplete")
   )
   df <- data.frame(c(dc, tdwg), stringsAsFactors = FALSE)
-  setNames(df, tolower(names(df)))
+  stats::setNames(df, tolower(names(df)))
 }
 
 ion_base <- function() 'http://www.organismnames.com/lsidmetadata.htm'
